@@ -7,7 +7,7 @@ def PSI(
     metrics="",
     category="performance",
     locale="en",
-    stratergy="desktop",
+    strategy="desktop",
     threshold="",
     links="",
     utm_campaign="",
@@ -20,7 +20,7 @@ def PSI(
             api_key=api_key,
             category=category,
             locale=locale,
-            stratergy=stratergy,
+            strategy=strategy,
             threshold=threshold,
             links=links,
             utm_campaign=utm_campaign,
@@ -38,7 +38,7 @@ def PSI(
             api_key=api_key,
             category=category,
             locale=locale,
-            stratergy=stratergy,
+            strategy=strategy,
             threshold=threshold,
             links=links,
             utm_campaign=utm_campaign,
